pro edistplot

;+
;This IDL routine reads and plots output from the Fortran 77
;Fokker-Planck code EFLUXPROG.  The output is in the file efluxout.txt.
;-

;Specify array sizes
ndy = 200 & ndy1 = 201 & ndx = 30 & ndz = 120 & ndc = 12 & ndh = 12

;Open output from Program EFLUXPROG
openr, unit, 'efluxout.txt', /get_lun

;READ OUTPUT into IDL variables and arrays

readf, unit, nc, nh, kfan, kitm, kkr
nc = fix(nc)
nh = fix(nh)
kfan = fix(kfan)
kitm = fix(kitm)
kkr = fix(kkr)
readf, unit, kb, kb1, khs, ksc, kab, kbc, kx, jy, iz
kb = fix(kb)
kb1 = fix(kb1)
khs = fix(khs)
ksc = fix(ksc)
kab = fix(kab)
kbc = fix(kbc)
kx = fix(kx)
jy = fix(jy)
iz = fix(iz)
readf, unit, ksy, ksmu
ksy = fix(ksy)
ksmu = fix(ksmu)
readf, unit, sh, adp, adpm
readf, unit, plow, phigh, emin, ebrk, emax, dniel
readf, unit, ybmin, ybmax, bmin, bmax, dbdy, ybexp
readf, unit, fzmc, zinc, mc2
readf, unit, x1
zn = fltarr(nc)
za = zn
ei = zn
FOR l = 0, nc-1 DO BEGIN
   readf, unit, znl, zal, eil
   zn[l] = znl & za[l] = zal & ei[l] = eil
ENDFOR
h = fltarr(nh)
dni = fltarr(nc, nh)
FOR l = 0, nh-1 DO BEGIN
   dnil = fltarr(nc)
   readf, unit, hl, dnil
   h[l] = hl
   dni[*, l] = dnil
ENDFOR
x = fltarr(kx)
readf, unit, x
ydy = fltarr(jy)
readf, unit, ydy
zdz = fltarr(iz)
readf, unit, zdz
readf, unit, imax, jmax, kmax
imax = fix(imax) & jmax = fix(jmax) & kmax = fix(kmax)
jmp1 = jmax+1
x = x[0:kmax-1]
pa = fltarr(kmax)
readf, unit, pa
y = fltarr(jmp1)
readf, unit, y
z = fltarr(imax)
readf, unit, z
thetab = fltarr(jmax)
readf, unit, thetab
schi = fltarr(jmax)
readf, unit, schi
hkm = fltarr(jmp1)
readf, unit, hkm
dn = fltarr(nc, jmp1)
FOR j = 0, jmax DO BEGIN
   dnil = fltarr(nc)
   readf, unit, hkm(j), dnil
   dn[*, j] = dnil
ENDFOR
noc = fltarr(jmp1)
readf, unit, noc
coldp = fltarr(jmp1)
readf, unit, coldp
bf = fltarr(jmp1)
readf, unit, bf
fz = fltarr(imax)
readf, unit, fz
xfm = fltarr(kmax)
readf, unit, xfm
flux = fltarr(jmax, kmax, imax)
FOR j = 0, jmax-1 DO FOR k = 0, kmax-1 DO BEGIN
   flux_jk = fltarr(imax)
   readf, unit, flux_jk
   flux[j, k, *] = flux_jk
ENDFOR

free_lun, unit


;SET COLOR TABLE
;
;  This makes colors on a PC behave in a manner similar to a workstation.
;
Device, Get_Visual_Depth = thisDepth
IF thisDepth GT 8 THEN Device, Decomposed = 0

;  Load "Rainbow" color table and set color 255 to white.

LoadCT, 13
TVLCT, 255, 255, 255, 255


;CREATE PLOTS

;Specify an array of five positions (0 to jmax-1) to plot
jplt = [0, 20, 70, 120, 150]

;Specify an array of five energies (0 to imax-1) to plot
iplt = [1, 2, 5, 6, 10]

paindex=0

window,0, Title = 'f(E) vs. E'
plot, z, flux(jplt(0),paindex,*), /xlog, /ylog, $
   xtitle = "Energy (keV)", ytitle = "Electron Distribution (electrons/cc/keV)"
oplot, z, flux(jplt(1),paindex,*), color=112
oplot, z, flux(jplt(2),paindex,*), color=208
oplot, z, flux(jplt(3),paindex,*), color=165
oplot, z, flux(jplt(4),paindex,*), color=254

;Create and position Legend for electron distribution function vs. energy graph
XYOutS, 2.0E+03, 1.0E+05, 'Pitch Angle = '+ strtrim((pa(paindex)),2)+' degrees', Size = 1.3
PlotS, [5.0E+03, 1.0E+04], [1.E+03,1.E+03], LineStyle=0, color=255
XYOutS, 1.2E+04, 1.0E+03, 'y= '+strtrim((y(jplt(0))/1e5),2)+' km', Size = 1.3
PlotS, [5.0E+03, 1.0E+04], [1.E+02,1.E+02], LineStyle=0, color=112
XYOutS, 1.2E+04, 1.0E+02, 'y= '+strtrim((y(jplt(1))/1e5),2)+' km', Size = 1.3
PlotS, [5.0E+03, 1.0E+04], [1.E+01,1.E+01], LineStyle=0, color=208
XYOutS, 1.2E+04, 1.0E+01, 'y= '+strtrim((y(jplt(2))/1e5),2)+' km', Size = 1.3
PlotS, [5.0E+03, 1.0E+04], [1.E+00,1.E+00], LineStyle=0, color=165
XYOutS, 1.2E+04, 1.0E+00, 'y= '+strtrim((y(jplt(3))/1e5),2)+' km', Size = 1.3
PlotS, [5.0E+03, 1.0E+04], [1.E-01,1.E-01], LineStyle=0, color=254
XYOutS, 1.2E+04, 1.0E-01, 'y= '+strtrim((y(jplt(4))/1e5),2)+' km', Size = 1.3

eindex=10
window,1, Title = 'f(E) vs. pitch angle'
plot, pa, flux(jplt(0),*,eindex), /ylog, xrange=[0, 180], yrange=[1.e-3,10000], xstyle=1, $
   xtitle='Pitch Angle (degrees)', ystyle=1, ytitle='Electron Distribution (electrons/cc/keV)'
oplot, pa, flux(jplt(1),*,eindex), color=112
oplot, pa, flux(jplt(2),*,eindex), color=208
oplot, pa, flux(jplt(3),*,eindex), color=165
oplot, pa, flux(jplt(4),*,eindex), color=254

;Create and position Legend for electron distribution function vs. pitch angle graph
XYOutS, 1.0E+01, 5.0E+02, 'E = '+ strtrim((z(eindex)),2)+' keV', Size = 1.3
PlotS, [1.0E+01, 3.0E+01], [2.E+02,2.E+02], LineStyle=0
XYOutS, 4.0E+01, 2.0E+02, 'y= '+strtrim((y(jplt(0))/1e5),2)+' km', Size = 1.3
PlotS, [1.0E+01, 3.0E+01], [1E+02,1E+02], LineStyle=0, color=112
XYOutS, 4.0E+01, 1E+02, 'y= '+strtrim((y(jplt(1))/1e5),2)+' km', Size = 1.3
PlotS, [1.0E+01, 3.0E+01], [5E+01,5E+01], LineStyle=0, color=208
XYOutS, 4.0E+01, 5E+01, 'y= '+strtrim((y(jplt(2))/1e5),2)+' km', Size = 1.3
PlotS, [1.0E+01, 3.0E+01], [2.3E+01,2.3E+01], LineStyle=0, color=165
XYOutS, 4.0E+01, 2.3E+01, 'y= '+strtrim((y(jplt(3))/1e5),2)+' km', Size = 1.3
PlotS, [1.0E+01, 3.0E+01], [1.1E+01,1.1E+01], LineStyle=0, color=254
XYOutS, 4.0E+01, 1.1E+01, 'y= '+strtrim((y(jplt(4))/1e5),2)+' km', Size = 1.3

window,2, Title = 'Column Depth & Magnetic Field vs. Distance'
plot, y, coldp, xrange=[0.0E+08, y(jmax)], xstyle=1, $
   yrange=[0.E+19, 1.E+21], ystyle=1, xmargin=[10,10], $
   xtitle='Distance from Top (cm)', ytitle='Column Depth (cm!U-2!N)'
axis, yaxis=1, yrange=[bmin-50.,bmax+50.], /save, ticklen=-0.02, color=112, $
   ytitle = 'Magnetic Field Strength (Gauss)'
oplot, y, bf, color=112

window,3, Title = 'f(E) vs. Distance'
plot, y, flux(*,paindex,iplt(0)), /ylog, xrange=[0., y(jmax)], xstyle=1, $
   yrange=[1.0E+02, 1.0E+08], ystyle=1, xmargin=[10,10], $
   xtitle = "Distance from Top (cm)", ytitle = "Electron Distribution (electrons/cc/keV)"
oplot, y, flux(*,paindex,iplt(1)), color=112
oplot, y, flux(*,paindex,iplt(2)), color=208
oplot, y, flux(*,paindex,iplt(3)), color=165
oplot, y, flux(*,paindex,iplt(4)), color=254

;Create and position Legend for electron distribution function vs. distance graph
XYOutS, 1.6E+09, 3.0E+07, 'Pitch Angle = '+ strtrim((pa(paindex)),2)+' degrees', Size = 1.3
PlotS, [2.0E+09, 2.3E+09], [1.E+07,1.E+07], LineStyle=0
XYOutS, 2.4E+09, 1.0E+07, 'E= '+strtrim((z(iplt(0))),2)+' keV', Size = 1.3
PlotS, [2.0E+09, 2.3E+09], [3.162E+06,3.162E+06], LineStyle=0, color=112
XYOutS, 2.4E+09, 3.162E+06, 'E= '+strtrim((z(iplt(1))),2)+' keV', Size = 1.3
PlotS, [2.0E+09, 2.3E+09], [1.E+06,1.E+06], LineStyle=0, color=208
XYOutS, 2.4E+09, 1.0E+06, 'E= '+strtrim((z(iplt(2))),2)+' keV', Size = 1.3
PlotS, [2.0E+09, 2.3E+09], [3.162E+05,3.162E+05], LineStyle=0, color=165
XYOutS, 2.4E+09, 3.162E+05, 'E= '+strtrim((z(iplt(3))),2)+' keV', Size = 1.3
PlotS, [2.0E+09, 2.3E+09], [1.E+05,1.E+05], LineStyle=0, color=254
XYOutS, 2.4E+09, 1.0E+05, 'E= '+strtrim((z(iplt(4))),2)+' keV', Size = 1.3

; Send Plot to Printer

;ok = Dialog_PrinterSetup()
;IF ok THEN BEGIN
;	thisDevice = !D.NAME
;	Set_Plot, 'PRINTER'
;plot, z*0.511, flux(0,0,*), /xlog, /ylog, $
;   xtitle = "Energy (MeV)", ytitle = "Electron Flux"
;oplot, z*0.511, flux(20,0,*)
;oplot, z*0.511, flux(70,0,*)
;oplot, z*0.511, flux(170,0,*)
;   	Device, /Close_Document
;   	Set_Plot, thisDevice
;ENDIF

END